@@ -66,7 +66,7 @@ if (orthogonal) {
   res <- x
   if (!inherits(res, "MIPCA")) stop("non convenient data")
   ncp <- max(axes)
-  reference <- PCA(res$res.imputePCA,scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
+  reference <- FactoMineR::PCA(res$res.imputePCA,scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
   rec.pca <- res$res.imputePCA
 #  rec <- reconst(reference,ncp)
 #  rec.pca <- as.matrix(res$call$X)
@@ -80,7 +80,7 @@ if (orthogonal) {
 ## rec.pca <- res$res.MI[,,i]
 for (i in 1:length(res$res.MI)){
  rec.pca <- res$res.MI[[i]]
- acpfin <- PCA(rec.pca, scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
+ acpfin <- FactoMineR::PCA(rec.pca, scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
 
  tourne <- procrustes(acpfin$ind$coord[,1:ncp], reference$ind$coord[,1:ncp],orthogonal = TRUE, translate = TRUE, magnify = TRUE)$rmat
 
@@ -96,7 +96,7 @@ for (i in 1:length(res$res.MI)){
 if (!is.null(main)) title <- main
 if ((choice=="all")|(choice=="ind.proc")){
   if (new.plot) dev.new()
-  oo=PCA(res.procrustes,ind.sup=c((nrow(res$call$X)+1):nrow(res.procrustes)),scale.unit=FALSE,graph=FALSE)
+  oo=FactoMineR::PCA(res.procrustes,ind.sup=c((nrow(res$call$X)+1):nrow(res.procrustes)),scale.unit=FALSE,graph=FALSE)
   oo$eig=reference$eig
 el=coord.ellipse(cbind.data.frame(as.factor(rep(rownames(res$call$X),res$call$nboot)),oo$ind.sup$coord[,axes]),level.conf=level.conf) 
   if (is.null(main)) title="Multiple imputation using Procrustes" 
@@ -112,7 +112,7 @@ el=coord.ellipse(cbind.data.frame(as.factor(rep(rownames(res$call$X),res$call$nb
 if ((choice=="all")|(choice=="dim")){
   if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
   colnames(res.dim)=paste("V",1:ncol(res.dim))
-  ooo=PCA(res.dim,quanti.sup=(ncol(res$call$X)+1):ncol(res.dim),scale.unit=res$call$scale,graph=FALSE)
+  ooo=FactoMineR::PCA(res.dim,quanti.sup=(ncol(res$call$X)+1):ncol(res.dim),scale.unit=res$call$scale,graph=FALSE)
   ooo$eig=reference$eig
   if (is.null(main)) title="Projection of the Principal Components"  
   plot(ooo,choi="var",axes=axes,title=title,label="none",new.plot=FALSE,invisible="var")
@@ -120,7 +120,7 @@ if ((choice=="all")|(choice=="dim")){
 
 if ((choice=="all")|(choice=="ind.supp")){
   if ((new.plot)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
-  oo=PCA(res.supp,ind.sup=c((nrow(res$call$X)+1):nrow(res.supp)),scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
+  oo=FactoMineR::PCA(res.supp,ind.sup=c((nrow(res$call$X)+1):nrow(res.supp)),scale.unit=res$call$scale,graph=FALSE,ncp=ncp)
   el=coord.ellipse(cbind.data.frame(as.factor(rep(rownames(res$call$X),res$call$nboot)),oo$ind.sup$coord),level.conf = level.conf,axes = axes)
   if (is.null(main)) title="Supplementary projection"    
   plot(oo,axes=axes,col.ind.sup=rep(1:nrow(res$call$X),res$call$nboot),label="ind",ellipse=el,col.quali="black",
@@ -144,7 +144,7 @@ if ((choice=="all")|(choice=="var")){
             "lightyellow", "maroon")
   colnames(res.var)=paste("V",1:ncol(res.var))
   colnames(res.var)[1:ncol(res$call$X)]=colnames(res$call$X)
-  oo=PCA(res.var,quanti.sup=c((ncol(res$call$X)+1):ncol(res.var)),scale.unit=res$call$scale,graph=FALSE)
+  oo=FactoMineR::PCA(res.var,quanti.sup=c((ncol(res$call$X)+1):ncol(res.var)),scale.unit=res$call$scale,graph=FALSE)
   if (is.null(main)) title="Variable representation"    
   plot(oo, axes=axes, choix = "var", title=title,invisible = "quanti.sup", col.hab = color[1:ncol(res$call$X)],new.plot=FALSE)
   for (k in 1:res$call$nboot) points(oo$quanti.sup$coord[((k-1)*ncol(res$call$X)+1):(k*ncol(res$call$X)),axes[1]], oo$quanti.sup$coord[((k-1)*ncol(res$call$X)+1):(k*ncol(res$call$X)),axes[2]], col = color[1:ncol(res$call$X)], pch = 15, cex = 0.3)
